==> pytorch_optimizer-2.2.1.tar.gz: pytorch_optimizer-2.2.1/pytorch_optimizer/base/exception.py <==
class NoSparseGradientError(Exception):
    """Raised when the gradient is sparse gradient

    :param optimizer_name: str. optimizer name.
    :param note: str. special conditions to note (default '').
    """

    def __init__(self, optimizer_name: str, note: str = ''):
        self.note: str = ' ' if note == '' else f' w/ {note} '
        self.message: str = f'[-] {optimizer_name}{self.note}does not support sparse gradient.'
        super().__init__(self.message)


class ZeroParameterSizeError(Exception):
    """Raised when the parameter size is 0"""

    def __init__(self):
        self.message: str = '[-] parameter size is 0'
        super().__init__(self.message)


class NoClosureError(Exception):
    """Raised when there's no closure function"""

    def __init__(self, optimizer_name: str):
        self.message: str = f'[-] {optimizer_name} requires closure.'
        super().__init__(self.message)


class NegativeLRError(Exception):
    """Raised when learning rate is negative"""

    def __init__(self, lr: float, lr_type: str = ''):
        self.note: str = 'learning rate' if lr_type == '' else lr_type
        self.message: str = f'[-] {self.note} must be positive. ({lr} > 0)'
        super().__init__(self.message)


class NegativeStepError(Exception):
    """Raised when step is negative"""

    def __init__(self, num_steps: int, step_type: str = ''):
        self.note: str = 'step' if step_type == '' else step_type
        self.message: str = f'[-] {self.note} must be positive. ({num_steps} > 0)'
        super().__init__(self.message)

==> pytorch_optimizer-2.3.1.tar.gz: pytorch_optimizer-2.3.1/pytorch_optimizer/base/exception.py <==
class NoSparseGradientError(Exception):
    """Raised when the gradient is sparse gradient.

    :param optimizer_name: str. optimizer name.
    :param note: str. special conditions to note (default '').
    """

    def __init__(self, optimizer_name: str, note: str = ''):
        self.note: str = ' ' if note == '' else f' w/ {note} '
        self.message: str = f'[-] {optimizer_name}{self.note}does not support sparse gradient.'
        super().__init__(self.message)


class ZeroParameterSizeError(Exception):
    """Raised when the parameter size is 0."""

    def __init__(self):
        self.message: str = '[-] parameter size is 0'
        super().__init__(self.message)


class NoClosureError(Exception):
    """Raised when there's no closure function."""

    def __init__(self, optimizer_name: str):
        self.message: str = f'[-] {optimizer_name} requires closure.'
        super().__init__(self.message)


class NegativeLRError(Exception):
    """Raised when learning rate is negative."""

    def __init__(self, lr: float, lr_type: str = ''):
        self.note: str = 'learning rate' if lr_type == '' else lr_type
        self.message: str = f'[-] {self.note} must be positive. ({lr} > 0)'
        super().__init__(self.message)


class NegativeStepError(Exception):
    """Raised when step is negative."""

    def __init__(self, num_steps: int, step_type: str = ''):
        self.note: str = 'step' if step_type == '' else step_type
        self.message: str = f'[-] {self.note} must be positive. ({num_steps} > 0)'
        super().__init__(self.message)
